#ifndef FERI_INITF
#define FERI_INITF
// --------------------------------------------
// -- Rigorous Numerics for Dissipative PDEs --
// --------------------------------------------
// --------------- Initializing ---------------
// --------------------------------------------
// by Ferenc Bartha
// http://www.math.u-szeged.hu/~barfer
// --------------------------------------------

#include "main.hpp"
#include "tools.hpp"
#include "structures.hpp"
#include "vectorfield.hpp"
#include "typedefs.hpp"

// --------------------------------------------

// converting a string to double
void stringToDouble(const std::string &S, double &result)
{
	std::istringstream ezmeg(S);
	ezmeg >> result;
}

// reading bounds from the input file
//  format:
//   alpha (interval/double)
//   beta  (interval/double)
//   gamma (interval/double)
//   nu    (interval/double)
//   L     (interval/double)
//   C    (double)
//   s    (double)
//
//   a_1  (interval/double)
//   ...
//   a_n  (interval/double)
//
//   we read maximum M a_i, if we have less, the rest is filled with zeros
void initFromFile(interval &alpha, interval &beta, interval &gamma, interval &nu, interval &L, MainType &W, TailType &T, char* S)
{
	std::string line, data1, data2;
	std::size_t found, found2;
	std::ifstream start_bounds (S);
	int i, j;
	double ddata1, ddata2;
	MainType zero_main;
	TailType zero_tail;



	W = zero_main;
	T = zero_tail;
	i = 1;

	if (start_bounds.is_open()) {

		//reading alpha, beta, gamma, nu, L

		for (j = 1; j <= 5; ++j) {

			std::getline (start_bounds, line);
			found = line.find("[");

			// interval entry
			if (found != std::string::npos) {

				found2 = line.find(",");
				data1 = line.substr(found + 1,found2 - found - 1);

				found = line.find("]");
				data2 = line.substr(found2 + 1, found - found2 - 1);

				stringToDouble(data1, ddata1);
				stringToDouble(data2, ddata2);

			// double entry
			} else {

				stringToDouble(line, ddata1);
				ddata2 = ddata1;

			}

			// filling in
			if (j == 1) {
				alpha = interval(ddata1, ddata2);
			} else if (j == 2) {
				beta = interval(ddata1, ddata2);
			} else if (j == 3) {
				gamma = interval(ddata1, ddata2);
			} else if (j == 4) {
				nu = interval(ddata1, ddata2);
			} else if (j == 5) {
				L = interval(ddata1, ddata2);
			}

		}

		// reading C and s
		std::getline (start_bounds, line);
		stringToDouble(line, ddata1);

		std::getline (start_bounds, line);
		stringToDouble(line, ddata2);

		T.C = interval(ddata1);
		T.s = interval(ddata2);

		// reading nodes
		while ( not(start_bounds.eof()) && (i <= M) )
		{
			std::getline (start_bounds, line);

			found = line.find("[");

			// interval entry
			if (found != std::string::npos) {

				found2 = line.find(",");
				data1 = line.substr(found + 1,found2 - found - 1);

				found = line.find("]");
				data2 = line.substr(found2 + 1, found - found2 - 1);

				stringToDouble(data1, ddata1);
				stringToDouble(data2, ddata2);

			// double entry
			} else {

				stringToDouble(line, ddata1);
				ddata2 = ddata1;

			}

			// filling in
			if (i <= m) {

				W(i) = interval(ddata1, ddata2);

			} else if (i <= M) {

				T.mid(i) = interval(ddata1, ddata2);

			}

			++i;
		}

		start_bounds.close();

	} else {

		ostream << "Unable to open input file" << std::endl;
		exit(0);

	}

}

// ~ end of file ~
#endif
