#ifndef FERI_MAIN
#define FERI_MAIN
// --------------------------------------------
// -- Rigorous Numerics for Dissipative PDEs --
// --------------------------------------------
// --------------- Main Header ----------------
// --------------------------------------------
// by Ferenc Bartha
// http://www.math.u-szeged.hu/~barfer
// --------------------------------------------

#include <iostream>
#include <fstream>
#include <cstdio>
#include <iomanip>
#include <typeinfo>
#include <string>
#include <cassert>

#include "capd/intervals/DoubleInterval.h"
#include "capd/krak/krak.h"

#include "capd/dynset/C0Set.h"
#include "capd/dynset/C1Set.h"
#include "capd/dynset/C2Set.h"
#include "capd/dynset/CnSet.h"

#include "capd/dynsys/FadMap.h"
#include "capd/dynsys/FadTaylor.h"
#include "capd/poincare/PoincareException.h"
#include "capd/poincare/BasicPoincareMap.h"
#include "capd/vectalg/Vector.hpp"
#include "capd/vectalg/Matrix.hpp"
#include "capd/matrixAlgorithms/capd2alglib.h"
#include "capd/matrixAlgorithms/matrixAlgorithmsLib.h"

#include "capd/vectalg/Norm.hpp"
#include "capd/map/Function.hpp"
#include "capd/map/Map.hpp"
#include "capd/map/CnMap.hpp"

#include "capd/dynsys/Taylor.hpp"
#include "capd/dynsys/BasicTaylor.hpp"
#include "capd/dynset/Rect2Set.hpp"
#include "capd/dynset/C1Rect2.hpp"

#include "capd/diffIncl/InclRect2Set.hpp"
#include "capd/diffIncl/DiffInclusionCW.hpp"
#include "capd/diffIncl/DiffInclusionLN.hpp"
#include "capd/diffIncl/DiffInclusion.hpp"
#include "capd/diffIncl/MultiMap.h"

//typedef capd::interval interval;
// --------------------------------------------

// DEBUG mode
//#define FERI_DEBUG

// GRAPHICS mode
#define FERI_GRAPHICS

// --------------------------------------------

const int		GLOBAL_CONST_order = 8;									// integration order for main nodes

const int		oPrecision = 16;										// number of digits to display

// --------------------------------------------

const char		outputFile[] = "output/output.txt";						// default output file

const char		inputFile[] = "data/datainput.txt";						// default starting data

// --------------------------------------------

const int		m = 40; 												// dimension of the Galerkin-projection

const int		M = 100;												// dimension of the subspace formed by the main and middle nodes

const int		nR = 100;												// dimension of non rigorous simulation

// ~ end of file ~
#endif
