#ifndef FERI_TOOLS
#define FERI_TOOLS
// --------------------------------------------
// -- Rigorous Numerics for Dissipative PDEs --
// --------------------------------------------
// ------------------ Tools -------------------
// --------------------------------------------
// by Ferenc Bartha
// http://www.math.u-szeged.hu/~barfer
// --------------------------------------------

#include "main.hpp"

// --------------------------------------------

int Indent_Length = 0;													// Indentation length

std::ofstream ostream;													// output stream

// --------------------------------------------

// opening and closing the output
void openOutput(char *S)
{
	std::cout << "Output is written to: " << S << std::endl << std::flush;
	ostream.open(S);
	ostream.precision(oPrecision);
	
}

void closeOutput()
{
	ostream.close();
}

// --------------------------------------------

// right endpoint modification
inline void setRBound(interval &i, const double &s)
{
	i = interval( i.leftBound(), s );
}

// left endpoint modification
inline void setLBound(interval &i, const double &s)
{
	i = interval( s, i.rightBound() );
}

// --------------------------------------------

// rigorous power with integer exponent
template<typename T_Base, typename T_Power>
inline interval power_to_int(const T_Base &a, const T_Power &b)
{
	return power( interval(a), int( rightBound( interval(b) ) ) );
}

// rigorous power
template<typename T_Base, typename T_Power>
inline interval power_up(const T_Base &a, const T_Power &b)
{
	return power( interval(a), interval(b) );
}

// --------------------------------------------

// Increases indent in debug output
void Indent_PlusLength()
{
	Indent_Length += 1;
}

// Decreases indent in debug output
void Indent_MinusLength()
{
	Indent_Length -= 1;
}

// Displays indent before debug output
void Indent_AddToOutput()
{
	for (int k = 0; k <= Indent_Length; ++k)
		ostream << " .";
	ostream << "-# ";
}

// --------------------------------------------

// interval inflation
interval inflate(const interval &a, const double &r)
{
	return (a - mid(a)) * r + mid(a);
}

// thin interval inflation from the left
interval left_infinc(const interval &a)
{
	interval addint(-1,0);
	double increase = 1e-16;

	return a + increase * addint;
}

// thin interval inflation from the right
interval right_infinc(const interval &a)
{
	interval addint(0,1);
	double increase = 1e-16;

	return a + increase * addint;
}

// thin interval inflation
interval infinc(const interval &a)
{
	interval addint(-1,1);
	double increase = 1e-16;

	return a + increase * addint;
}

// interval intersection
interval Intersect(const interval &a, const interval &b)
{
	interval c;



	if (intersection(a,b,c)) {
		return c;
	} else {

		Indent_AddToOutput();
		ostream << "Intersect: Empty intersection!" << a << " ^ " << b << std::endl;

		return c;
	}
}

// ~ end of file ~
#endif
